/*!
 * @huiwei-form/component-elm-checkbox v4.0.0
 * (c) 2018-2023 huiwei-form
 * Github https://github.com/xaboy/form-create with checkbox
 * Released under the MIT License.
 */
import { defineComponent, toRef, resolveComponent, createVNode, mergeProps } from 'vue';

function getSlot(slots, exclude) {
  return Object.keys(slots).reduce((lst, name) => {
    if (!exclude || exclude.indexOf(name) === -1) {
      lst.push(slots[name]);
    }
    return lst;
  }, []);
}

const NAME = 'fcCheckbox';
var Checkbox = defineComponent({
  name: NAME,
  inheritAttrs: false,
  props: {
    formCreateInject: Object,
    modelValue: {
      type: Array,
      default: () => []
    },
    type: String
  },
  emits: ['update:modelValue'],
  setup(props, _) {
    const options = toRef(props.formCreateInject, 'options', []);
    const value = toRef(props, 'modelValue');
    const _options = () => {
      return Array.isArray(options.value) ? options.value : [];
    };
    return {
      options: _options,
      value,
      onInput(n) {
        _.emit('update:modelValue', n);
      }
    };
  },
  render() {
    var _this$$slots$default, _this$$slots;
    const name = this.type === 'button' ? 'ElCheckboxButton' : 'ElCheckbox';
    const Type = resolveComponent(name);
    return createVNode(resolveComponent("ElCheckboxGroup"), mergeProps(this.$attrs, {
      "modelValue": this.value,
      "onUpdate:modelValue": this.onInput
    }), {
      default: () => [this.options().map((opt, index) => {
        const props = {
          ...opt
        };
        const value = props.value;
        delete props.value;
        return createVNode(Type, mergeProps(props, {
          "label": value,
          "key": name + index + '-' + opt.value
        }), {
          default: () => [props.label || props.value || '']
        });
      }), (_this$$slots$default = (_this$$slots = this.$slots).default) === null || _this$$slots$default === void 0 ? void 0 : _this$$slots$default.call(_this$$slots)],
      ...getSlot(this.$slots, ['default'])
    });
  }
});

export { Checkbox as default };
